@@ -10,8 +10,12 @@ from pydantic import BaseModel
 from graphql.type.definition import (
     GraphQLEnumType,
 )
+import keyword
 
 
+class EnumsPluginsError(Exception):
+    pass
+
 class EnumsPluginConfig(BaseModel):
     skip_underscore: bool = True
     prepend: str = ""
@@ -38,12 +42,16 @@ def generate_enums(
             continue
 
         name = f"{config.prepend_enum}{key}{config.append_enum}"
-        fields = [ast.Expr(value=ast.Constant(value=type.description))]
+        fields = [ast.Expr(value=ast.Constant(value=type.description))] if type.description else []
 
         for value_key, value in type.values.items():
+            if keyword.iskeyword(value_key):
+                value_key = f"{value_key}_"
+
+
             assign = ast.Assign(
                 targets=[ast.Name(id=str(value_key), ctx=ast.Store())],
-                value=ast.Constant(value=str(value.value)),
+                value=ast.Constant(value=value.value),
             )
 
             potential_comment = (
